﻿using System;
using System.Collections.Generic;
using System.IO;
using ffxiah_wfa;

public class ffxiah
{
    private int date;
    private string error;
    private const string FFXIAH = "ffxiah.out";
    private Dictionary<string, Dictionary<string, string>> ItemPrices;
    private Dictionary<string, string> ItemTypes;
    private Dictionary<string, string> Servers;

    public ffxiah()
    {
        Dictionary<string, string> dictionary = new Dictionary<string, string>();
        dictionary.Add("All Types", "999");
        dictionary.Add("Weapons", "255");
        dictionary.Add("Hand to Hand", "1");
        dictionary.Add("Daggers", "2");
        dictionary.Add("Swords", "3");
        dictionary.Add("Great Swords", "4");
        dictionary.Add("Great Axes", "6");
        dictionary.Add("Scythes", "7");
        dictionary.Add("Polearms", "8");
        dictionary.Add("Katana", "9");
        dictionary.Add("Great Katana", "10");
        dictionary.Add("Clubs", "11");
        dictionary.Add("Ranged", "13");
        dictionary.Add("Ammo&Misc", "246");
        dictionary.Add("Pet Items", "48");
        dictionary.Add("Ammunition", "15");
        dictionary.Add("Instruments", "14");
        dictionary.Add("Breads & Rice", "56");
        dictionary.Add("Armor", "254");
        dictionary.Add("Shields", "16");
        dictionary.Add("Head", "17");
        dictionary.Add("Neck", "22");
        dictionary.Add("Body", "18");
        dictionary.Add("Hands", "19");
        dictionary.Add("Legs", "20");
        dictionary.Add("Feet", "21");
        dictionary.Add("Back", "26");
        dictionary.Add("Earrings", "24");
        dictionary.Add("Rings", "25");
        dictionary.Add("Scrolls", "253");
        dictionary.Add("Songs", "32");
        dictionary.Add("Ninjutsu", "31");
        dictionary.Add("Summoning", "30");
        dictionary.Add("Dice", "60");
        dictionary.Add("Medicines", "33");
        dictionary.Add("Goldsmithing", "39");
        dictionary.Add("Materials", "250");
        dictionary.Add("Alchemy", "44");
        dictionary.Add("Woodworking", "43");
        dictionary.Add("Bonecraft", "42");
        dictionary.Add("Leathercraft", "41");
        dictionary.Add("Clothcraft", "40");
        dictionary.Add("Smithing", "38");
        dictionary.Add("Food", "249");
        dictionary.Add("Meals", "245");
        dictionary.Add("Meat & Eggs", "52");
        dictionary.Add("Seafood", "53");
        dictionary.Add("Vegetables", "54");
        dictionary.Add("Sweets", "57");
        dictionary.Add("Drinks", "58");
        dictionary.Add("Ingredients", "59");
        dictionary.Add("Fish", "51");
        dictionary.Add("Crystals", "35");
        dictionary.Add("White Magic", "28");
        dictionary.Add("Misc", "46");
        dictionary.Add("Beast-Made", "50");
        dictionary.Add("Cards", "36");
        dictionary.Add("Ninja Tools", "49");
        dictionary.Add("Cursed Items", "37");
        dictionary.Add("Automatons", "61");
        dictionary.Add("Axes", "5");
        dictionary.Add("Staves", "12");
        dictionary.Add("Grips", "62");
        dictionary.Add("Furnishings", "34");
        dictionary.Add("Waist", "23");
        dictionary.Add("Fishing Gear", "47");
        dictionary.Add("Soups", "55");
        dictionary.Add("Others", "247");
        dictionary.Add("Black Magic", "29");
        this.ItemTypes = dictionary;
        Dictionary<string, string> dictionary2 = new Dictionary<string, string>();
        dictionary2.Add("Odin", "12");
        dictionary2.Add("Asura", "28");
        dictionary2.Add("Bahamut", "1");
        dictionary2.Add("Bismarck", "25");
        dictionary2.Add("Carbuncle", "6");
        dictionary2.Add("Cerberus", "23");
        dictionary2.Add("Fenrir", "7");
        dictionary2.Add("Lakshmi", "27");
        dictionary2.Add("Leviathan", "11");
        dictionary2.Add("Phoenix", "5");
        dictionary2.Add("Quetzalcoatl", "16");
        dictionary2.Add("Ragnarok", "20");
        dictionary2.Add("Shiva", "2");
        dictionary2.Add("Siren", "17");
        dictionary2.Add("Sylph", "8");
        dictionary2.Add("Valefor", "9");
        dictionary2.Add("All Servers", "999");
        this.Servers = dictionary2;
        this.ItemPrices = new Dictionary<string, Dictionary<string, string>>();
        this.ReadPrices();
        TimeSpan span = (TimeSpan) (DateTime.UtcNow - new DateTime(0x7b2, 1, 1, 0, 0, 0));
        this.date = (int) span.TotalSeconds;
    }

    public string CheckStack(string name)
    {
        if (name.Contains("(stack)"))
        {
            return "1";
        }
        return "0";
    }

    public double getAdjustedRate(string rate)
    {
        double num = (this.ToDouble(rate) / 365.0) * 100000.0;
        return Math.Round(num, MidpointRounding.AwayFromZero);
    }

    public string getError()
    {
        return this.error;
    }

    public string getInventory(double rate, int outer, int inter, Random r)
    {
        int num = 0;
        for (int i = 0; i < outer; i++)
        {
            int num3 = 0;
            for (int j = 0; j < inter; j++)
            {
                if (rate > r.Next(0x186a0))
                {
                    num3++;
                }
            }
            if (num3 > num)
            {
                num = num3;
            }
        }
        return num.ToString();
    }

    public string getName(string itemid)
    {
        return this.ItemPrices[itemid]["name"];
    }

    public string getPrice(string itemid, string server, string stack)
    {
        if (stack == "1")
        {
            return this.ItemPrices[itemid + "s"][server + "p"];
        }
        return this.ItemPrices[itemid][server + "p"];
    }

    public string getRate(string itemid, string server, string stack)
    {
        double num;
        if (stack == "1")
        {
            num = this.ToDouble(this.ItemPrices[itemid + "s"][server + "r"]);
            return this.TestRate(num).ToString("F5");
        }
        num = this.ToDouble(this.ItemPrices[itemid][server + "r"]);
        return this.TestRate(num).ToString("F5");
    }

    public string getServerID(string server)
    {
        return this.Servers[server];
    }

    public string getTypeID(string type)
    {
        return this.ItemTypes[type];
    }

    private void ReadPrices()
    {
        if (!File.Exists("ffxiah.out"))
        {
            this.error = "The file could not be read. Please verify 'ffxiah.out' is in the same directory as 'dspAH.exe'.";
        }
        else
        {
            using (StreamReader reader = File.OpenText("ffxiah.out"))
            {
                string str;
                int num = 0;
                while ((str = reader.ReadLine()) != null)
                {
                    if (num == 0)
                    {
                        num = 1;
                    }
                    else
                    {
                        string[] strArray = str.Replace("\n", "").Split(new char[] { '\t' });
                        Dictionary<string, string> dictionary2 = new Dictionary<string, string>();
                        dictionary2.Add("name", strArray[1]);
                        dictionary2.Add("stack", strArray[2]);
                        dictionary2.Add("1r", strArray[3]);
                        dictionary2.Add("1p", strArray[4]);
                        dictionary2.Add("2r", strArray[5]);
                        dictionary2.Add("2p", strArray[6]);
                        dictionary2.Add("5r", strArray[7]);
                        dictionary2.Add("5p", strArray[8]);
                        dictionary2.Add("6r", strArray[9]);
                        dictionary2.Add("6p", strArray[10]);
                        dictionary2.Add("7r", strArray[11]);
                        dictionary2.Add("7p", strArray[12]);
                        dictionary2.Add("8r", strArray[13]);
                        dictionary2.Add("8p", strArray[14]);
                        dictionary2.Add("9r", strArray[15]);
                        dictionary2.Add("9p", strArray[0x10]);
                        dictionary2.Add("11r", strArray[0x11]);
                        dictionary2.Add("11p", strArray[0x12]);
                        dictionary2.Add("12r", strArray[0x13]);
                        dictionary2.Add("12p", strArray[20]);
                        dictionary2.Add("16r", strArray[0x15]);
                        dictionary2.Add("16p", strArray[0x16]);
                        dictionary2.Add("17r", strArray[0x17]);
                        dictionary2.Add("17p", strArray[0x18]);
                        dictionary2.Add("20r", strArray[0x19]);
                        dictionary2.Add("20p", strArray[0x1a]);
                        dictionary2.Add("23r", strArray[0x1b]);
                        dictionary2.Add("23p", strArray[0x1c]);
                        dictionary2.Add("25r", strArray[0x1d]);
                        dictionary2.Add("25p", strArray[30]);
                        dictionary2.Add("27r", strArray[0x1f]);
                        dictionary2.Add("27p", strArray[0x20]);
                        dictionary2.Add("28r", strArray[0x21]);
                        dictionary2.Add("28p", strArray[0x22]);
                        dictionary2.Add("999p", strArray[0x23]);
                        dictionary2.Add("999r", strArray[0x24]);
                        Dictionary<string, string> dictionary = dictionary2;
                        if (strArray[2] == "1")
                        {
                            this.ItemPrices.Add(strArray[0] + "s", dictionary);
                        }
                        else
                        {
                            this.ItemPrices.Add(strArray[0], dictionary);
                        }
                    }
                }
            }
        }
    }

    private double TestRate(double rate)
    {
        if (rate > 0.0)
        {
            return rate;
        }
        return 0.005;
    }

    public double ToDouble(string s)
    {
        double result = 0.0;
        double.TryParse(s, out result);
        return result;
    }

    public int ToInt(string s)
    {
        int result = 0;
        int.TryParse(s, out result);
        return result;
    }

    public string Date
    {
        get
        {
            return this.date.ToString();
        }
    }
}

